# © 2022 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from datetime import timedelta

from odoo import api, fields, models


class ScopInstance(models.Model):
    _name = "scop.instance"
    _description = "Instances"
    _order = "date desc"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    name = fields.Char("Instance", compute="_compute_name")
    date = fields.Datetime("Date", required=True)
    date_start = fields.Datetime("Début", compute="_compute_dates", store=True)
    date_stop = fields.Datetime("Fin", compute="_compute_dates", store=True)
    comments = fields.Text("Commentaires")

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    def _compute_name(self):
        for r in self:
            r.name = "Instance - " + r.date.strftime("%d/%m/%Y")

    @api.depends("date")
    def _compute_dates(self):
        for r in self:
            r.date_start = r.date + timedelta(hours=7)
            r.date_stop = r.date + timedelta(hours=19)
